@@ -1,14 +1,25 @@
 """Base cluster inteface."""
 
 from abc import ABC, abstractmethod
-from typing import List
+from typing import Any, List
 
+from blackcap.configs import config_registry
+from blackcap.messenger import messenger_registry
 from blackcap.schemas.schedule import Schedule
 
+config = config_registry.get_config()
+messenger = messenger_registry.get_messenger(config.MESSENGER)
+
 
 class BaseCluster(ABC):
     """Base cluster interface."""
 
+    CONFIG_KEY = "CLUSTER"
+    CONFIG_KEY_DEF_VAL = "ARGO"
+
+    # Change this value in custom auther implementations.
+    CONFIG_KEY_VAL = "ARGO"
+
     @abstractmethod
     def prepare_job(self: "BaseCluster", schedule: Schedule) -> None:
         """Prepare job for submission.
@@ -41,11 +52,12 @@ class BaseCluster(ABC):
         """
         pass
 
-    def process_schedule_msg(self: "BaseCluster", schedule: Schedule) -> None:
+    def process_schedule_msg(self: "BaseCluster", messenger_msg: Any) -> None:
         """Submit job to the cluster.
 
         Args:
-            schedule (Schedule): Schedule Object
+            messenger_msg (Any): message in Messenger specific format
         """
+        schedule = messenger.parse_messenger_msg(messenger_msg)
         self.prepare_job(schedule)
         self.submit_job(schedule)
